#
# spec file for package python-pygeos
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pygeos
Version:        0.14
Release:        1.1
Summary:        GEOS wrapped in numpy ufuncs
License:        BSD-3-Clause
URL:            https://github.com/pygeos/pygeos
Source:         https://files.pythonhosted.org/packages/source/p/pygeos/pygeos-%{version}.tar.gz
BuildRequires:  %{python_module Cython with %python-Cython < 3}
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 61}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  libgeos-devel
BuildRequires:  python-rpm-macros
Requires:       python-numpy >= 1.13
# SECTION test requirements
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
PyGEOS is a C/Python library with vectorized geometry functions.
The geometry operations are done in the open-source geometry library GEOS.
PyGEOS wraps these operations in NumPy ufuncs providing a performance
improvement when operating on arrays of geometries.

%prep
%setup -q -n pygeos-%{version}
mv pygeos/tests/ .

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand rm %{buildroot}%{$python_sitearch}/pygeos/_{geometry,geos}.c
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
mv pygeos .pygeos
%pytest_arch -rs -k 'not test_float_arg_array'
mv .pygeos pygeos

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitearch}/pygeos
%{python_sitearch}/pygeos-%{version}.dist-info

%changelog
* Tue Aug 29 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.14
  * Dropped support for Python 3.6 (#458).
  * Fixed unittests for GEOS 3.11 (#458).
- Limit to Cython 0.X
- Use PEP517 macros instead of deprecated setup.py
* Tue Sep 27 2022 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Update to v0.13
* Sun Dec 13 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.8
